@@ -2,7 +2,7 @@ import altair
 import opentracing
 import typing
 
-from .globals import get_active_span, get_fallback, set_active_span
+from .globals import get_active_span, get_fallback, set_active_span, debug
 from .tracer import tracer
 
 __all__ = ["altair_renderer"]
@@ -15,14 +15,16 @@ def altair_renderer(spec):
     """
     An altair renderer that serves our custom mimetype with ibis support.
     """
-    if get_fallback():
+    active_span = get_active_span()
+    # If we don't have an active span, this means we have gone through the data transform
+    # on any ibis expressions.s
+    if get_fallback() or not active_span:
         return altair.vegalite.v3.display.default_renderer(spec)
 
-    active_span = get_active_span()
-    assert active_span
     injected_span: typing.Dict = {}
     tracer.inject(active_span, opentracing.Format.TEXT_MAP, injected_span)
     active_span.log_kv({"vega-lite:initial": spec})
+    debug("vega-lite:initial", spec)
     active_span.finish()
     set_active_span(None)
 
